@@ -1,6 +1,8 @@
 context("canvasXpress BASE")
 
-data1.df  <- data.frame(a = c(1:3), b = c("A", "B", "C"),
+# Data preparation
+data1.df  <- data.frame(a         = c(1:3),
+                        b         = c("A", "B", "C"),
                         row.names = c("row1", "row2", "row3"))
 data1.m   <- matrix(1:20, nrow = 5)
 data1.l   <- list(y = data1.df, data2 = data1.df)
@@ -60,20 +62,19 @@ test_that("Incorrect GraphType", {
 })
 
 test_that("Name mismatches", {
-    expect_error(canvasXpress(data = data1.df,
+    expect_error(canvasXpress(data     = data1.df,
                               smpAnnot = data1.var),
                  regexp = "Row names in smpAnnot are different from column names in data")
-    expect_silent(canvasXpress(data = data1.df,
+    expect_silent(canvasXpress(data     = data1.df,
                                smpAnnot = data1.smp))
 
-    expect_error(canvasXpress(data = data1.df,
+    expect_error(canvasXpress(data     = data1.df,
                               varAnnot = data1.smp),
                  regexp = "Row names in varAnnot are different from row names in data")
-    expect_silent(canvasXpress(data = data1.df,
+    expect_silent(canvasXpress(data     = data1.df,
                                varAnnot = data1.var))
 })
 
-
 # Shiny Functionality
 
 test_that("Shiny Render", {
@@ -82,8 +83,7 @@ test_that("Shiny Render", {
 
 test_that("Shiny Examples", {
     expect_error(cxShinyExample("badexample"),
-                 regexp = "Valid examples are: 'example1', 'example2'")
+                 regexp = "Valid examples are: 'example1', 'example2', 'example3'")
     expect_message(cxShinyExample(NULL),
-                 regexp = "Valid examples are: 'example1', 'example2'")
+                 regexp = "Valid examples are: 'example1', 'example2', 'example3'")
 })
-
