@@ -1,10 +1,15 @@
 context("canvasXpress Charts - Network")
 
 
-n <- read.table(get_data( "cX-lesmiserable-nodes.txt.gz"), header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
-e <- read.table(get_data( "cX-lesmiserable-edges.txt.gz"), header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
-
 test_that("network as data list items", {
+    tryCatch({
+        n <- read.table("https://www.canvasxpress.org/data/cX-lesmiserable-nodes.txt", header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+        e <- read.table("https://www.canvasxpress.org/data/cX-lesmiserable-edges.txt", header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+    },
+    error = function(e) {
+        skip('Unable to read data files')
+    })
+
     result <- canvasXpress(data        = list(nodeData = n, edgeData = e),
                            colorNodeBy = "group",
                            edgeWidth   = 2,
@@ -15,6 +20,14 @@ test_that("network as data list items", {
 })
 
 test_that("network data requires both nodes and edges", {
+    tryCatch({
+        n <- read.table("https://www.canvasxpress.org/data/cX-lesmiserable-nodes.txt", header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+        e <- read.table("https://www.canvasxpress.org/data/cX-lesmiserable-edges.txt", header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+    },
+    error = function(e) {
+        skip('Unable to read data files')
+    })
+
     expect_error(canvasXpress(data        = list(nodeData = n),
                               graphType   = "Network"),
                  regexp = "edgeData cannot be NULL!")
@@ -27,6 +40,14 @@ test_that("network data requires both nodes and edges", {
 })
 
 test_that("network data types", {
+    tryCatch({
+        n <- read.table("https://www.canvasxpress.org/data/cX-lesmiserable-nodes.txt", header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+        e <- read.table("https://www.canvasxpress.org/data/cX-lesmiserable-edges.txt", header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+    },
+    error = function(e) {
+        skip('Unable to read data files')
+    })
+
     expect_error(canvasXpress(nodeData    = 2,
                               edgeData    = e,
                               graphType   = "Network"),
