@@ -20,3 +20,11 @@ test_that("cXridgeline4", {
 test_that("cXridgeline5", {
     check_ui_test(cXridgeline5())
 })
+
+test_that("cXridgeline6", {
+    check_ui_test(cXridgeline6())
+})
+
+test_that("cXridgeline7", {
+    check_ui_test(cXridgeline7())
+})
